spray_cpp: Low-level functions that call C++ source code

spray_cppR Documentation

Low-level functions that call C++ source code

Description

Low-level functions that call C++ source code, as detailed in the automatically generated RcppExports.R file.

Usage

spray_maker(M, d)
spray_add(M1, d1, M2, d2)
spray_mult(M1, d1, M2, d2)
spray_overwrite(M1, d1, M2, d2)
spray_accessor(M, d, Mindex)
spray_setter(M1, d1, M2, d2)
spray_equality(M1, d1, M2, d2)
spray_asum_include(M, d, n)
spray_asum_exclude(M, d, n)
spray_deriv(M, d, n)
spray_pmax(M1, d1, M2, d2)
spray_power(M, d, pow)

Arguments

M, M1, M2, Mindex

Integer valued matrices with rows corresponding to array indices

d, d1, d2

Vector of values corresponding to nonzero array entries

n

Integer vector corresponding to dimensions to sum over for the sum functions

pow

Nonnegative integer for spray_power()

Value

These functions return a two-element list which is coerced to an object of class spray by function spraymaker().

Note

These functions aren't really designed for the end-user.

Function spray_equality() cannot simply check for equality of $value because the order of the index rows is not specified in a spray object. Function spray_crush() has been removed as it is redundant.

Author(s)

Robin K. S. Hankin

See Also

spraymaker,spray


spray documentation built on May 28, 2026, 5:09 p.m.